# TapyrusApiClient::TokenApi

All URIs are relative to *https://ap-01.tapyrus.chaintope.com/api/v1*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**burn_token**](TokenApi.md#burn_token) | **DELETE** /tokens/{token_id}/burn | トークンの焼却 |
| [**get_tokens**](TokenApi.md#get_tokens) | **GET** /tokens | トークンの総量取得 |
| [**issue_token**](TokenApi.md#issue_token) | **POST** /tokens/issue | トークンの新規発行 |
| [**reissue_token**](TokenApi.md#reissue_token) | **POST** /tokens/{token_id}/reissue | トークンの再発行 |
| [**transfer_token**](TokenApi.md#transfer_token) | **PUT** /tokens/{token_id}/transfer | トークンの送付 |


## burn_token

> burn_token(token_id, opts)

トークンの焼却

任意の数のトークンを焼却します。

### Examples

```ruby
require 'time'
require 'tapyrus-api-client'
# setup authorization
TapyrusApiClient.configure do |config|end

api_instance = TapyrusApiClient::TokenApi.new
token_id = 'token_id_example' # String | トークンの識別子。
opts = {
  amount: 56 # Integer | `amount`を受け取り、指定した量のトークンを焼却します。 `amount`が未入力の場合全てのトークンを焼却します。 
}

begin
  # トークンの焼却
  api_instance.burn_token(token_id, opts)
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->burn_token: #{e}"
end
```

#### Using the burn_token_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> burn_token_with_http_info(token_id, opts)

```ruby
begin
  # トークンの焼却
  data, status_code, headers = api_instance.burn_token_with_http_info(token_id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->burn_token_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **token_id** | **String** | トークンの識別子。 |  |
| **amount** | **Integer** | &#x60;amount&#x60;を受け取り、指定した量のトークンを焼却します。 &#x60;amount&#x60;が未入力の場合全てのトークンを焼却します。  | [optional] |

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_tokens

> <Array<GetTokensResponse>> get_tokens(opts)

トークンの総量取得

所有するトークンの総量を取得し、トークン識別子(`token_id`)ごとに総量(`amount`)を一覧で表示します。

### Examples

```ruby
require 'time'
require 'tapyrus-api-client'
# setup authorization
TapyrusApiClient.configure do |config|end

api_instance = TapyrusApiClient::TokenApi.new
opts = {
  confirmation_only: true # Boolean | オプションで`confirmation_only`を設定でき、`true`の場合ブロックチェーン上で承認済みのトークンのみを取得し、`false`の場合未承認のトークンも含めて取得します。デフォルトは`true`です。
}

begin
  # トークンの総量取得
  result = api_instance.get_tokens(opts)
  p result
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->get_tokens: #{e}"
end
```

#### Using the get_tokens_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<GetTokensResponse>>, Integer, Hash)> get_tokens_with_http_info(opts)

```ruby
begin
  # トークンの総量取得
  data, status_code, headers = api_instance.get_tokens_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<GetTokensResponse>>
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->get_tokens_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **confirmation_only** | **Boolean** | オプションで&#x60;confirmation_only&#x60;を設定でき、&#x60;true&#x60;の場合ブロックチェーン上で承認済みのトークンのみを取得し、&#x60;false&#x60;の場合未承認のトークンも含めて取得します。デフォルトは&#x60;true&#x60;です。 | [optional] |

### Return type

[**Array&lt;GetTokensResponse&gt;**](GetTokensResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## issue_token

> <TokenResponse> issue_token(opts)

トークンの新規発行

任意の数のトークンを新規発行します。

### Examples

```ruby
require 'time'
require 'tapyrus-api-client'
# setup authorization
TapyrusApiClient.configure do |config|end

api_instance = TapyrusApiClient::TokenApi.new
opts = {
  issue_token_request: TapyrusApiClient::IssueTokenRequest.new({amount: 100}) # IssueTokenRequest | `amount`を受け取り指定した数のトークンを新規発行します。 任意で`token_type`を設定し、トークンの種類を指定できます。 `token_type`が未指定な場合、再発行可能なトークンが発行されます。 トークンの種類は以下の通りです。 - 1: 再発行可能なトークン - 2: 再発行不可能なトークン - 3: NFT  また、`token_type`が未指定または`1`の場合、任意でトークン識別子`id`を指定することで、指定したトークン識別子のトークンを再発行します。 
}

begin
  # トークンの新規発行
  result = api_instance.issue_token(opts)
  p result
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->issue_token: #{e}"
end
```

#### Using the issue_token_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TokenResponse>, Integer, Hash)> issue_token_with_http_info(opts)

```ruby
begin
  # トークンの新規発行
  data, status_code, headers = api_instance.issue_token_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TokenResponse>
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->issue_token_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **issue_token_request** | [**IssueTokenRequest**](IssueTokenRequest.md) | &#x60;amount&#x60;を受け取り指定した数のトークンを新規発行します。 任意で&#x60;token_type&#x60;を設定し、トークンの種類を指定できます。 &#x60;token_type&#x60;が未指定な場合、再発行可能なトークンが発行されます。 トークンの種類は以下の通りです。 - 1: 再発行可能なトークン - 2: 再発行不可能なトークン - 3: NFT  また、&#x60;token_type&#x60;が未指定または&#x60;1&#x60;の場合、任意でトークン識別子&#x60;id&#x60;を指定することで、指定したトークン識別子のトークンを再発行します。  | [optional] |

### Return type

[**TokenResponse**](TokenResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## reissue_token

> <TokenResponse> reissue_token(token_id, opts)

トークンの再発行

指定した識別子を持つ再発行可能なトークンを任意の量再発行します。

### Examples

```ruby
require 'time'
require 'tapyrus-api-client'
# setup authorization
TapyrusApiClient.configure do |config|end

api_instance = TapyrusApiClient::TokenApi.new
token_id = 'token_id_example' # String | トークンの識別子。
opts = {
  reissue_token_request: TapyrusApiClient::ReissueTokenRequest.new({amount: 100}) # ReissueTokenRequest | 
}

begin
  # トークンの再発行
  result = api_instance.reissue_token(token_id, opts)
  p result
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->reissue_token: #{e}"
end
```

#### Using the reissue_token_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TokenResponse>, Integer, Hash)> reissue_token_with_http_info(token_id, opts)

```ruby
begin
  # トークンの再発行
  data, status_code, headers = api_instance.reissue_token_with_http_info(token_id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TokenResponse>
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->reissue_token_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **token_id** | **String** | トークンの識別子。 |  |
| **reissue_token_request** | [**ReissueTokenRequest**](ReissueTokenRequest.md) |  | [optional] |

### Return type

[**TokenResponse**](TokenResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## transfer_token

> <TokenResponse> transfer_token(token_id, transfer_token_request)

トークンの送付

任意の数のトークンを指定したアドレスに対して送付します。

### Examples

```ruby
require 'time'
require 'tapyrus-api-client'
# setup authorization
TapyrusApiClient.configure do |config|end

api_instance = TapyrusApiClient::TokenApi.new
token_id = 'token_id_example' # String | トークンの識別子。
transfer_token_request = TapyrusApiClient::TransferTokenRequest.new({address: '1CY6TSSARn8rAFD9chCghX5B7j4PKR8S1a'}) # TransferTokenRequest | `address`でトークンを送付する相手のアドレスを指定し、`amount`で送付するトークンの量を指定します。

begin
  # トークンの送付
  result = api_instance.transfer_token(token_id, transfer_token_request)
  p result
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->transfer_token: #{e}"
end
```

#### Using the transfer_token_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TokenResponse>, Integer, Hash)> transfer_token_with_http_info(token_id, transfer_token_request)

```ruby
begin
  # トークンの送付
  data, status_code, headers = api_instance.transfer_token_with_http_info(token_id, transfer_token_request)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TokenResponse>
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling TokenApi->transfer_token_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **token_id** | **String** | トークンの識別子。 |  |
| **transfer_token_request** | [**TransferTokenRequest**](TransferTokenRequest.md) | &#x60;address&#x60;でトークンを送付する相手のアドレスを指定し、&#x60;amount&#x60;で送付するトークンの量を指定します。 |  |

### Return type

[**TokenResponse**](TokenResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

