# TapyrusApiClient::UserApi

All URIs are relative to *https://ap-01.tapyrus.chaintope.com/api/v1*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**create_user**](UserApi.md#create_user) | **POST** /users | ユーザを作成します。 |
| [**get_user_info**](UserApi.md#get_user_info) | **GET** /userinfo | ユーザの情報を返します。 |


## create_user

> create_user(create_user_request)

ユーザを作成します。

OpenID Connect を使った認証で得た id_token と access_token を Tapyrus API へ登録しユーザを作成します。すでにユーザが存在する場合は認証情報を更新します。

### Examples

```ruby
require 'time'
require 'tapyrus-api-client'

api_instance = TapyrusApiClient::UserApi.new
create_user_request = TapyrusApiClient::CreateUserRequest.new({id_token: 'eyJhbGciOiJSUzI1NiIsImtpZCI6IjFlOWdkazcifQ.ewogImlzcyI6ICJodHRwOi8vc2VydmVyLmV4YW1wbGUuY29tIiwKICJzdWIiOiAiMjQ4Mjg5NzYxMDAxIiwKICJhdWQiOiAiczZCaGRSa3F0MyIsCiAibm9uY2UiOiAibi0wUzZfV3pBMk1qIiwKICJleHAiOiAxMzExMjgxOTcwLAogImlhdCI6IDEzMTEyODA5NzAKfQ.ggW8hZ1EuVLuxNuuIJKX_V8a_OMXzR0EHR9R6jgdqrOOF4daGU96Sr_P6qJp6IcmD3HP99Obi1PRs-cwh3LO-p146waJ8IhehcwL7F09JdijmBqkvPeB2T9CJNqeGpe-gccMg4vfKjkM8FcGvnzZUN4_KSP0aAp1tOJ1zZwgjxqGByKHiOtX7TpdQyHE5lcMiKPXfEIQILVq0pc_E2DzL7emopWoaoZTF_m0_N0YzFC6g6EJbOEoRoSK5hoDalrcvRYLSrQAZZKflyuVCyixEoV9GfNQC3_osjzw2PAithfubEEBLuVVk4XUVrWOLrLl0nx7RkKU8NXNHq-rvKMzqg', issuer: 'https://server.example.com', client_id: 's6BhdRkqt3', access_token: 'SlAV32hkKG'}) # CreateUserRequest | 

begin
  # ユーザを作成します。
  api_instance.create_user(create_user_request)
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling UserApi->create_user: #{e}"
end
```

#### Using the create_user_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> create_user_with_http_info(create_user_request)

```ruby
begin
  # ユーザを作成します。
  data, status_code, headers = api_instance.create_user_with_http_info(create_user_request)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling UserApi->create_user_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **create_user_request** | [**CreateUserRequest**](CreateUserRequest.md) |  |  |

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: Not defined


## get_user_info

> <UserinfoResponse> get_user_info(opts)

ユーザの情報を返します。

ユーザの`id`,`balance`, `address`の情報を返します。

### Examples

```ruby
require 'time'
require 'tapyrus-api-client'
# setup authorization
TapyrusApiClient.configure do |config|end

api_instance = TapyrusApiClient::UserApi.new
opts = {
  confirmation_only: true # Boolean | オプションで`confirmation_only`を設定でき、`true`の場合ブロックチェーン上で承認済みのtpc・トークンのみを取得し、`false`の場合未承認のtpc・トークンも含めて取得します。デフォルトは`true`です。
}

begin
  # ユーザの情報を返します。
  result = api_instance.get_user_info(opts)
  p result
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling UserApi->get_user_info: #{e}"
end
```

#### Using the get_user_info_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<UserinfoResponse>, Integer, Hash)> get_user_info_with_http_info(opts)

```ruby
begin
  # ユーザの情報を返します。
  data, status_code, headers = api_instance.get_user_info_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <UserinfoResponse>
rescue TapyrusApiClient::ApiError => e
  puts "Error when calling UserApi->get_user_info_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **confirmation_only** | **Boolean** | オプションで&#x60;confirmation_only&#x60;を設定でき、&#x60;true&#x60;の場合ブロックチェーン上で承認済みのtpc・トークンのみを取得し、&#x60;false&#x60;の場合未承認のtpc・トークンも含めて取得します。デフォルトは&#x60;true&#x60;です。 | [optional] |

### Return type

[**UserinfoResponse**](UserinfoResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

